---
name: Feature request
about: Suggest an idea for {{ cookiecutter.project_name }}
title: ''
labels: 'enhancement'
assignees: ''
---

**Is your feature request related to a problem? Please describe.**  
A clear and concise description of what the problem is.  
Ex: "I'm always frustrated when [...]"

**Describe the solution you'd like**  
What would you like to happen? Describe the ideal feature or behavior.

**Describe alternatives you've considered**  
What other solutions or features did you think about? Why didn’t they work?

**Additional context**  
Include screenshots, mockups, diagrams, or any other supporting material here.
